@@ -90,8 +90,13 @@ readRAST6 <- function(vname, cat=NULL, ignore.stderr = FALSE,
 		    close(con)
 		    lres <- as.list(res)
 		    names(lres) <- colnames(res)
-		    lres$min <- floor(as.double(lres$min))
-		    vNODATA <- floor(lres$min) - 1
+		    if (!is.numeric(lres$min) || 
+			!is.finite(as.double(lres$min))) 
+			    vNODATA <- as.integer(999)
+		    else {
+			lres$min <- floor(as.double(lres$min))
+		        vNODATA <- floor(lres$min) - 1
+		    }
 		} else {
 		    if (!is.finite(NODATA) || !is.numeric(NODATA))
 			stop("invalid NODATA value")
